38#include <hip/hip_runtime.h>
50 void *
cr,
void *
cs,
void *
ct,
51 void *
dx,
void *
dy,
void *
dz,
60 void *
cr,
void *
cs,
void *
ct,
61 void *
dx,
void *
dy,
void *
dz,
74#define CASE_1D(LX, C) \
75 hipLaunchKernelGGL( HIP_KERNEL_NAME( \
76 convect_scalar_kernel_1d<real, LX, NEKO_CHUNKS(LX, C)> ),\
77 nblcks, NEKO_CHUNKS_NTHRDS(LX, C), 0, \
78 (hipStream_t) glb_cmd_queue, \
79 (real *) du, (real *) u, \
80 (real *) cr, (real *) cs, (real *) ct, \
81 (real *) dx, (real *) dy, (real *) dz); \
82 HIP_CHECK(hipGetLastError());
85#define CASE_1D_SEL(LX, SEL) \
87 case 0: CASE_1D(LX, 0); break; \
88 case 1: CASE_1D(LX, 1); break; \
89 case 2: CASE_1D(LX, 2); break; \
90 default: CASE_1D(LX, 3); break; \
93#define CASE_KSTEP(LX, C) \
94 hipLaunchKernelGGL( HIP_KERNEL_NAME( \
95 convect_scalar_kernel_kstep<real, LX, NEKO_EB(LX, C)> ),\
96 NEKO_EB_NBLCKS(*nel, LX, C), NEKO_EB_NTHRDS(LX, C), 0, \
97 (hipStream_t) glb_cmd_queue, \
98 (real *) du, (real *) u, \
99 (real *) cr, (real *) cs, (real *) ct, \
100 (real *) dx, (real *) dy, (real *) dz, *nel); \
101 HIP_CHECK(hipGetLastError());
104#define CASE_KSTEP_SEL(LX, SEL) \
106 case 0: CASE_KSTEP(LX, 0); break; \
107 case 1: CASE_KSTEP(LX, 1); break; \
108 default: CASE_KSTEP(LX, 2); break; \
113 if(autotune[LX] == 0 ) { \
114 autotune[LX]=tune_convect_scalar<LX>(du, u, \
117 nel, lx, &autotune_eb[LX], \
119 } else if (autotune[LX] == 1 ) { \
120 CASE_1D_SEL(LX, autotune_ch[LX]); \
121 } else if (autotune[LX] == 2 ) { \
122 CASE_KSTEP_SEL(LX, autotune_eb[LX]); \
126#define CASE_LARGE(LX) \
168template < const
int LX >
170 void *
cr,
void *
cs,
void *
ct,
171 void *
dx,
void *
dy,
void *
dz,
247 for (
int r = 0; r <
rounds; r++) {
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void const T *__restrict__ const T *__restrict__ cr
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ cs
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ ct
#define NEKO_CHUNKS_CANDIDATES
#define NEKO_EB_CANDIDATES
#define NEKO_EB_SEL(LX, SEL)
#define NEKO_CHUNKS_SEL(LX, SEL)
#define NEKO_TUNE_TIME(T, LAUNCH, LX, C, ITERS)
static int neko_tune_rounds()
#define NEKO_TUNE_LOG(LX, T1, T2)
#define NEKO_TUNE_BEST(T, BEST, N)
static int neko_tune_iters()
static int neko_chunks_env()
static int neko_eb_sweep()
void log_error(char *msg)
void log_message(char *msg)
void log_section(char *msg)
#define CASE_KSTEP_SEL(LX, SEL)
#define CASE_1D_SEL(LX, SEL)
#define CASE_KSTEP(LX, C)
void hip_convect_scalar(void *du, void *u, void *cr, void *cs, void *ct, void *dx, void *dy, void *dz, int *nel, int *lx)
int tune_convect_scalar(void *du, void *u, void *cr, void *cs, void *ct, void *dx, void *dy, void *dz, int *nel, int *lx, int *eb_sel, int *ch_sel)